function [] = demo(FileName)

% [] = demo(FileName)
% Demo function to demonstrate counting yeast colonies on a Petri dish.
% Filename is an image file to be processed, in JPG or TIFF format
% Possible dimensions: 560x752, 768x1024, 1536x2048
%
% Author Jan Schier <schier@utia.cas.cz>
% Date 2009/08/04
% 
% Copyright
% (c) 2009 Dept. of Signal Processing
% Institute of Information Theory and Automation
% Academy of Sciences of the Czech Republic, Prague
%
% http://sp.utia.cz
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Softwared Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% You are free to distribute this software under Version 2.1
% of the GNU General Public License.

if nargin<1
    disp('Usage: demo(''FileName'')');
    return
end

% Load image, convert to greyscale
img = LoadImg(FileName);

% Call the preprocessor function
[Dish, DishBW, PetriX, PetriY, R_ROI, TotArea] = DishPreprocessor(img);
[area, NBlobs, BlobCenter] = Counting(Dish, DishBW, TotArea);

% Position of the output display on the screen
scrsz = get(0,'ScreenSize');
height = .6*scrsz(4);
width = .8*scrsz(3);
XGUI = .1*scrsz(3);
YGUI = .1*scrsz(4);
FigPos = [XGUI,YGUI,width,height];

LineWidth=2;

R1Measured = R_ROI;

% Prepare circle marking the region of interest

tmpY = CircleSeg45(R1Measured, 1, 0);
tmpX = 0:(length(tmpY)-1);

ROICircleX = PetriX+[tmpX tmpY(end:-1:1)  tmpY  tmpX(end:-1:1)];
ROICircleY = PetriY+[tmpY tmpX(end:-1:1) -tmpX -tmpY(end:-1:1)];

ROICircleX = [ROICircleX 2*PetriX-ROICircleX(end:-1:1)];
ROICircleY = [ROICircleY ROICircleY(end:-1:1)];

figure('Position',FigPos);

subplot(1,2,1);
% Original image, with the center of the dish and the circle of ROI
image(img);
axis image
axis off
h=gcf;
colormap(gray(256));
set(h,'Name',FileName,'NumberTitle','Off');
hold
plot(ROICircleX+1, ROICircleY+1, '-g');
plot(PetriX,PetriY,'b*');
title('Original image, location of dish center and ROI');
% Thresholded image (only colonies), limited to the circle of ROI
subplot(1,2,2)
image(Dish);
h=gcf;
set(h,'Name',FileName,'NumberTitle','Off');
hold
plot(ROICircleX-PetriX+R_ROI+1, ROICircleY-PetriY+R_ROI+1, '-g');
plot(BlobCenter(:,2), BlobCenter(:,1), 'b+');
if NBlobs>0
    title(['Relative area: ' num2str(area)...
        '%, Number of colonies: ' num2str(NBlobs)]);
else
    title(['Relative area: ' num2str(area)]);
end
colormap(gray(256));
axis square
axis off
pause
close
end